<?php
/**
 * @file
 * Provides node utility functions
 */
/**
 * Returns a node property
 *
 * @param $nid
 *   The node ID
 * @param $field
 * 	 One of the following strings
 *   	title = Node title
 *   	uid = Author uid
 *   	type = Node type
 *   	status = Published status
 *   	sticky = Sticky at top of lists
 *   	promote = Promoted to front page
 * @return
 *   The specified node property
 */
function simple_utilities_nodeField($nid, $field) {
  //$result = db_query("SELECT node.title AS node_title FROM {node} node WHERE node.nid = :nid", array(':nid' => $nid))->fetchCol();
  $query = db_select('node', 'n');
  $query
  	->condition('n.nid', $nid)
  	->addField('n', $field);
  $result = $query->execute()->fetchCol();
  return $result[0];
}

/**
 * Returns a node's taxonomy
 *
 * @param $nid
 *   The node ID
 * @return
 *   An indexed array of objects of node taxamony data with the following properties
 *   'tid' = The term ID 
 *   'term_name' = The term name 
 *   'description' = The term description
 *   'weight' = The term weight
 *   'vid' = The vocabulary ID 
 *   'vocabulary_name' = The vocabulary name 
 */
function simple_utilities_nodeTaxonomy($nid) {
  //$result = db_query("SELECT ttd.tid AS tid, ttd.vid AS vid, ttd.name AS term_name, ttd.description AS description, ttd.weight AS weight, vocab.name as vocabulary_name FROM {taxonomy_term_data} ttd INNER JOIN {taxonomy_index} ti ON ti.tid = ttd.tid INNER JOIN {taxonomy_vocabulary} vocab ON ttd.vid = vocab.vid WHERE ti.nid = :nid", array(':nid' => $nid))->fetchAll();
  $query = db_select('taxonomy_term_data', 'ttd');
  $query->join('taxonomy_index', 'ti', 'ti.tid = ttd.tid');
  $query->join('taxonomy_vocabulary', 'vocab', 'ttd.vid = vocab.vid');
  $query->condition('ti.nid', $nid);
  $query->addField('ttd', 'tid', 'tid');
  $query->addField('ttd', 'vid', 'vid');
  $query->addField('ttd', 'name', 'term_name');
  $query->addField('ttd', 'description', 'description');
  $query->addField('ttd', 'weight', 'weight');
  $query->addField('vocab', 'name', 'vocabulary_name');
  $result = $query->execute()->fetchAll();
  return $result;
}

/**
 * Returns a node's last revision date and creation date.
 *
 * @param $nid
 *   The node ID
 * @return
 *   Object of timestamps with the following properties
 *   'created' = The creation date of the Node
 *   'changed' = The date of the last change
 */
function simple_utilities_nodeDates($nid) {
  $query = db_select('node', 'n');
  $query->join('node_revision', 'nr', 'n.vid = nr.vid');
  $query->condition('n.nid', $nid);
  $query->addField('nr', 'timestamp', 'changed');
  $query->addField('n', 'created', 'created');
  $result = $query->execute()->fetchAll();
  return $result;
}


/**
 * Returns a data on the node's last comment.
 *
 * @param $nid
 *   The node ID
 * @return
 *   An object with the following properties
 *   'cid' = Comment ID
 *   'timestamp' = Comment timestamp
 *   'uid' = Comment author user id,
 *   'username' = Comment author username
 *   'count' = The total number of comment on the node.
 */
function simple_utilities_nodeLastCommentData($nid) {
  $query = db_select('node', 'n');
  $query->join('node_comment_statistics', 'ncs', 'n.nid = ncs.nid');
  $query->leftJoin('users', 'ncs_users', 'ncs.last_comment_uid = ncs_users.uid');
  $query->addField('ncs', 'comment_count', 'count');
  $query->addField('n', 'comment', 'cid');
  $query->addField('ncs', 'last_comment_uid', 'uid');
  $query->addField('ncs', 'last_comment_timestamp', 'timestamp');
  $query->addField('ncs', 'comment_count', 'count');
  $query->addExpression('COALESCE(ncs_users.name, ncs.last_comment_name)', 'username');
  $result = $query->execute()->fetchAll();
  return $result;
}
