<?php
/**
 * @file
 * Provides user utility functions
 */
/**
 * Returns a user name
 *
 * @param $uid
 *   The user ID as an integer or the user email as a string
 * @param $field
 *   The field you want to return
 *   	name
 *   	status
 *   	created
 *   	login = the user's last login
 *   	access = the user's last access
 * @return
 *   The data in the field specified
 */
function simple_utilities_userField($arg, $field) {
  if (is_int($arg)) {
    $c1 = 'u.uid';
  } else {
    $c1 = 'u.mail';
  }
  $query = db_select('users', 'u');
  $query->condition($c1, $arg);
  $query->addField('u', $field);
  $result = $query->execute()->fetchCol();
  return $result[0];
}

/**
 * Returns a user email
 *
 * @param $uid
 *   The user ID
 * @return
 *   The user email
 */
function simple_utilities_userEmail($uid) {
  $query = db_select('users', 'u');
  $query->condition('u.uid', $uid);
  $query->addField('u', 'mail');
  $result = $query->execute()->fetchCol();
  return $result[0];
}

/**
 * Returns a user ID
 *
 * @param $mail
 *   The user email address
 * @return
 *   The user ID
 */
function simple_utilities_userID($mail) {
  $query = db_select('users', 'u');
  $query->condition('u.mail', $mail);
  $query->addField('u', 'uid');
  $result = $query->execute()->fetchCol();
  return $result[0];
}

/**
 * Returns a user's picture data
 *
 * @param $uid
 * The user ID as an integer or the user email as a string
 * @return
 *   An object of file Data
 *   filename
 *   path_to_file = Path to File 
 *   mimetype
 *   size = in Bytes
 *   status
 *   timetamp = Upload date
 *   fid = File ID
 */
function simple_utilities_userPicture($arg) {  
  if (is_int($arg)) {
    $c1 = 'u.uid';
  } else {
    $c1 = 'u.mail';
  }
  $query = db_select('users', 'u');
  $query->condition($c1, $arg);
  $query->addField('u', 'picture');
  $fid = $query->execute()->fetchCol();
  
  $result = simple_utilities_fileData($fid[0]);
  $result->fid = $fid[0];
  return $result;
}

/**
 * Returns a user's roles
 *
 * @param $uid
 *   The user ID as an integer or the user email as a string
 * @return
 *   An associative array of roles
 *   'role' = role name
 *   'rid' = role ID 
 *   'weight' = role weight
 */
function simple_utilities_userRoles($arg) {
  $query = db_select('role', 'r');
  $query->join('users_roles', 'ur', 'r.rid = ur.rid ');
  if (is_int($arg)) {
  	$query->condition('ur.uid', $arg);
  } else {
  	$subquery = db_select('users', 'u');
  	$subquery->condition('u.mail', $arg);
  	$subquery->addField('u', 'uid');
  	$uid = $subquery->execute()->fetchCol();
  	$query->condition('ur.uid', $uid[0]);
  }
  $query->addField('r', 'name', 'role');
  $query->addField('r', 'rid');
  $query->addField('r', 'weight');
  $result = $query->execute()->fetchAll();
  return $result;
}